#[non_exhaustive]pub enum DispatchStrategy {
RoundRobin,
LeastLoaded,
}Expand description
Strategy used to pick a worker slot in the pool.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RoundRobin
Assign tasks round-robin across available worker slots.
LeastLoaded
Prefer slots with the lowest active task count (future extension).