#[non_exhaustive]pub enum OverflowPolicy {
Block,
Reject,
DropOldest,
}Expand description
Overflow behavior applied when the submission queue is full.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Block
Wait until queue capacity becomes available.
Reject
Reject the new submission immediately.
DropOldest
Drop the oldest queued task and enqueue the new submission.