pub struct WorkerScheduler { /* private fields */ }Expand description
Scheduler backed by a canonical rskit-worker pool configuration.
The scheduler is deterministic and does not create background work by itself.
Execution backpressure is enforced by the bounded Pool produced by WorkerScheduler::pool.
Implementations
Sourceimpl WorkerScheduler
impl WorkerScheduler
Sourcepub fn new(pool_name: impl Into<String>, config: SchedulerConfig) -> Self
pub fn new(pool_name: impl Into<String>, config: SchedulerConfig) -> Self
Create a scheduler targeting a named worker pool.