TaskHandle

Struct TaskHandle 

pub struct TaskHandle<O: Clone + Send + 'static> {
    pub id: Uuid,
    /* private fields */
}
Handle returned to a caller after submitting a task to the pool.

  • result() awaits the final task output.
  • events() returns a broadcast receiver for intermediate Events.
  • cancel() requests cooperative cancellation.

Fields

id: Uuid

Unique identifier assigned to this task by the pool.

Implementations

Source

impl<O: Clone + Send + 'static> TaskHandle<O>

pub async fn result(self) -> AppResult<O>

Await the final result of the task.

pub fn events(&self) -> Receiver<Event<O>>

Get a new broadcast receiver for intermediate events.

pub fn cancel(&self)

Signal the task to cancel.

pub fn cancel_token(&self) -> CancellationToken

Clone the cancellation token so it can be stored separately (e.g., for cancelling after the handle is consumed by result()).